@@ -8,7 +8,9 @@
 #'
 #' @param obstacles A \code{SpatialPolygonsDataFrame} object specifying the obstacles outline
 #' @param obstacles_height_field Name of attribute in \code{obstacles} with extrusion height for each feature
-#' @param solar_pos A matrix with one row and two columns; first column is the solar azimuth (in decimal degrees from North), second column is sun elevation (in decimal degrees)
+#' @param solar_pos A \code{matrix} with one row and two columns; first column is the solar azimuth (in decimal degrees from North), second column is sun elevation (in decimal degrees)
+#' @param time When \code{solar_pos} is unspecified, \code{time} can be passed to automatically calculate \code{solar_pos} based on the time and the centroid of \code{obstacles}, using function \code{maptools::solarpos}. In such case \code{obstacles} must have a defined CRS (not \code{NA}). The \code{time} value must be a \code{POSIXct} or \code{POSIXlt} object
+
 #' @param b Buffer size for shadow footprints of individual segments of a given polygon; used to eliminate minor internal holes in the resulting shadow polygon.
 #'
 #' @return A \code{SpatialPolygonsDataFrame} object representing shadow footprint, plus buildings outline. Object length is the same as that of the input \code{obstacles}, with an individual footprint feature for each obstacle.
@@ -18,21 +20,28 @@
 #' \url{https://www.dropbox.com/s/k7q3oa5z69lnw15/Thesis_Morel_Weisthal.pdf?dl=1}
 #'
 #' @examples
-#' data(rishon)
-#' location = rgeos::gCentroid(rishon)
+#' location = rgeos::gCentroid(build)
 #' time = as.POSIXct("2004-12-24 13:30:00", tz = "Asia/Jerusalem")
 #' solar_pos = maptools::solarpos(
 #'   matrix(c(34.7767978098526, 31.9665936050395), ncol = 2),
 #'   time
 #'   )
-#' footprint =
+#' footprint1 =               ## Using 'solar_pos'
 #'   shadowFootprint(
-#'     obstacles = rishon,
+#'     obstacles = build,
 #'     obstacles_height_field = "BLDG_HT",
 #'     solar_pos = solar_pos
 #'     )
+#' footprint2 =               ## Using 'time'
+#'   shadowFootprint(
+#'     obstacles = build,
+#'     obstacles_height_field = "BLDG_HT",
+#'     time = time
+#'     )
+#' all.equal(footprint1, footprint2)
+#' footprint = footprint1
 #' plot(footprint, col = adjustcolor("lightgrey", alpha.f = 0.5))
-#' plot(rishon, add = TRUE, col = "darkgrey")
+#' plot(build, add = TRUE, col = "darkgrey")
 #'
 #' @export
 #' @name shadowFootprint
@@ -40,11 +49,9 @@
 NULL
 
 setGeneric("shadowFootprint", function(
-  # surface,
   obstacles,
   obstacles_height_field,
-  solar_pos,
-  b = 0.01
+  ...
 ) {
   standardGeneric("shadowFootprint")
 })
@@ -56,15 +63,14 @@ setMethod(
   f = "shadowFootprint",
 
   signature = c(
-    # surface = "missing",
     obstacles = "SpatialPolygonsDataFrame"
   ),
 
   function(
-    # surface,
     obstacles,
     obstacles_height_field,
-    solar_pos,
+    solar_pos = solarpos2(obstacles, time),
+    time = NULL,
     b = 0.01
     ) {
 
